==> haskell-boxes-0.1.5-33-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-boxes.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 boxes
version:              0.1.5
visibility:           public
id:                   boxes-0.1.5-BJVPCfn77Hg9DhWvj6qAWW
key:                  boxes-0.1.5-BJVPCfn77Hg9DhWvj6qAWW
license:              BSD-3-Clause
maintainer:           David Feuer <David.Feuer@gmail.com>
author:               Brent Yorgey
synopsis:             2D text pretty-printing library
description:
    A pretty-printing library for laying out text in
    two dimensions, using a simple box model.

category:             Text
abi:                  40223bab530dca82087db5e42fb2f99f
exposed:              True
exposed-modules:      Text.PrettyPrint.Boxes
import-dirs:          /usr/lib/ghc-8.8.2/site-local/boxes-0.1.5
library-dirs:         /usr/lib/ghc-8.8.2/site-local/boxes-0.1.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.2/boxes-0.1.5
hs-libraries:         HSboxes-0.1.5-BJVPCfn77Hg9DhWvj6qAWW
depends:              base-4.13.0.0 split-0.2.3.3-1RyPZVF4QuTGi4xFw9VQUK
haddock-interfaces:   /usr/share/doc/haskell-boxes/html/boxes.haddock
haddock-html:         /usr/share/doc/haskell-boxes/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-boxes-0.1.5-37-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-boxes.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 boxes
version:              0.1.5
visibility:           public
id:                   boxes-0.1.5-AYNLdaSn22A7dOwqOT6LLx
key:                  boxes-0.1.5-AYNLdaSn22A7dOwqOT6LLx
license:              BSD-3-Clause
maintainer:           David Feuer <David.Feuer@gmail.com>
author:               Brent Yorgey
synopsis:             2D text pretty-printing library
description:
    A pretty-printing library for laying out text in
    two dimensions, using a simple box model.

category:             Text
abi:                  0aad52cadd42861c8486c214810d35cf
exposed:              True
exposed-modules:      Text.PrettyPrint.Boxes
import-dirs:          /usr/lib/ghc-8.8.3/site-local/boxes-0.1.5
library-dirs:         /usr/lib/ghc-8.8.3/site-local/boxes-0.1.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/boxes-0.1.5
hs-libraries:         HSboxes-0.1.5-AYNLdaSn22A7dOwqOT6LLx
depends:              base-4.13.0.0 split-0.2.3.4-Iq7NGP1D6FgEqhhoAnwS8D
haddock-interfaces:   /usr/share/doc/haskell-boxes/html/boxes.haddock
haddock-html:         /usr/share/doc/haskell-boxes/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
